##  Using Diagram Templates
Diagram templates let you reuse standardized rules for visualizing your inventory data. They help you create consistent diagrams without starting from scratch.
With diagram templates, you can:
  * View a dynamic preview that updates in real time based on your current inventory data.
  * Explore dependencies directly in the live diagram.
  * Generate a static diagram when you need a fixed, editable snapshot for documentation, sharing, or audits.
  * Start quickly with preset templates, such as an application context view, that include predefined fact sheet types, relations, and views.


For more information about creating and previewing diagram templates, see: [Diagram Templates](https://help.sap.com/docs/leanix/ea/diagram-templates?locale=en-US&state=PRODUCTION&version=CLOUD "Diagram templates provide reusable, standardized rules for visualizing live inventory data, enabling dynamic exploration and consistent documentation of your landscape. Use them to efficiently create, manage, and share up-to-date diagrams for analysis, stakeholder communication, and audits.")
